@@ -254,4 +254,22 @@ QByteArray BacktraceGenerator::sentryPayload() const
     return m_sentryPayload;
 };
 
+void BacktraceGenerator::setBackendFailed()
+{
+    // Shouldn't have been set yet
+    Q_ASSERT(!m_proc);
+    Q_ASSERT(!m_temp);
+    m_proc = nullptr;
+    m_temp = nullptr;
+
+    m_state = FailedToStart;
+    Q_EMIT stateChanged();
+    Q_EMIT failedToStart();
+}
+
+bool BacktraceGenerator::hasAnyFailure()
+{
+    return m_state == State::Failed || m_state == State::FailedToStart;
+}
+
 #include "moc_backtracegenerator.cpp"
